@@ -467,22 +467,15 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                 }
                 if (button) {
                     // in ios/android buttons do not necessarily get focus when clicked
-                    // so we need to do it manually
-                    //let os = qx.core.Environment.get('os.name');
-                    //if (os == 'android' || os == 'ios'){
-                        // let orig_action = action;
-                        // action = () => {
-                        //     if (button.isFocusable()) {
-                        //         button.focus();
-                        //     }
-                        //     setTimeout(orig_action.bind(this),1);
-                        // }
-                        button.addListener('touchstart', () => { 
-                            if (button.isFocusable()) {
-                               button.focus();
-                            }
-                        }, this );
-                    //}        
+                    // so we need to do it manually, since this happens on different
+                    // browsers, chances are this is not a bug but by design :)
+
+                    // once https://github.com/qooxdoo/qooxdoo/pull/10632 is released
+                    // this here can go away
+                    button.addListenerOnce('appear',() => {
+                      let el = button.getContentElement().getDomElement();
+                      button.addListener('touchstart', () => { el.focus(); }, this);
+                    });
                     button.addListener('execute', action, this);
                     if (btCfg.addToMenu) {
                         menues[btCfg.addToMenu].add(button);
